@@ -30,9 +30,13 @@ class Extractor(object):
         self.export = kwargs.get('export')
         self.export_file = kwargs.get('export_file')
         self.export_content = kwargs.get('export_content', False)
-        self.hashtags = [hashtag.lower() for hashtag in kwargs.get('hashtags', '').replace('#', '').split(',')]
 
-        # optional options
+        if kwargs.get('hashtags', '') is not None:
+            self.hashtags = [hashtag.lower() for hashtag in kwargs.get('hashtags', '').replace('#', '').split(',')]
+        else:
+            self.hashtags = []
+
+            # optional options
         args = ['since', 'until', 'post_id', 'group_id', 'event_id', 'author_id', 'feed_id',
                 'active_only', 'create_ranking', 'create_gexf', 'node_attributes', 'additional_node_attributes',
                 'joining_column']
@@ -86,16 +90,17 @@ class Extractor(object):
         elif self.export == 'Interactions':
             extractor = InteractionExtractor(extractor=self)
 
-        print("Extracting data... ")
+        print("Extracting data... ", end=" ")
         await extractor.extract()
         print("DONE")
 
-
         print("Converting results... ", end=" ")
+        print(extractor.nodes)
+        print(f'file = {self.export_file}')
         nodes_pd = extractor.nodes.to_pandas(self)
         print("DONE")
 
-        try:
+        if self.config.get('MISC', 'save_file') == 'True':
             print("Saving CSV file... ", end=' ')
             # .to_csv(f'{self.config.get("MISC", "output_dir")}/{self.csv}', index=False, sep=";")
             nodes_pd = nodes_pd.applymap(lambda x: x.encode('unicode_escape')
@@ -104,11 +109,7 @@ class Extractor(object):
                     .to_excel(f'{self.config.get("MISC", "output_dir")}/{self.export_file}', sheet_name='Results', index=False)
             print("DONE")
 
-            return nodes_pd
-        except:
-            print(1)
-
-
+        return nodes_pd
 
     async def set_token(self):
         with open(self.token) as file:
